pub fn run_shell_command(command_str: &str) -> Result<()>
Executes a shell command and returns an error if it fails.
Returns an error if the command fails to execute or returns a non-zero exit status.